@@ -34,8 +34,9 @@ import fcntl
 from common.utils import configuration as cfg
 import unittest2 as ut
 from common.utils.applicationstest import CommonTrackerApplicationTest as CommonTrackerApplicationTest
+from common.utils.helpers import log
 
-MINER_FS_IDLE_TIMEOUT = 30
+MINER_FS_IDLE_TIMEOUT = 5
 
 class TrackerCameraPicturesApplicationTests (CommonTrackerApplicationTest):
 
@@ -88,7 +89,7 @@ class TrackerCameraPicturesApplicationTests (CommonTrackerApplicationTest):
         self.assertEquals (self.get_urn_count_by_url (dest_fileuri), 1)
 
         # Clean the new file so the test directory is as before
-        print "Remove and wait"
+        log ("Remove and wait")
         os.remove (dest_filepath)
         self.system.tracker_miner_fs_wait_for_idle (MINER_FS_IDLE_TIMEOUT)
         self.assertEquals (self.get_urn_count_by_url (dest_fileuri), 0)
@@ -174,7 +175,7 @@ class TrackerCameraPicturesApplicationTests (CommonTrackerApplicationTest):
         self.assertEquals (self.get_urn_count_by_url (dest_fileuri), 1)
 
         # Clean the new file so the test directory is as before
-        print "Remove and wait"
+        log ("Remove and wait")
         os.remove (dest_filepath)
         self.system.tracker_miner_fs_wait_for_idle (MINER_FS_IDLE_TIMEOUT)
         self.assertEquals (self.get_urn_count_by_url (dest_fileuri), 0)
@@ -231,7 +232,7 @@ class TrackerCameraVideosApplicationTests (CommonTrackerApplicationTest):
         self.assertEquals (self.get_urn_count_by_url (dest_fileuri), 1)
 
         # Clean the new file so the test directory is as before
-        print "Remove and wait"
+        log ("Remove and wait")
         os.remove (dest_filepath)
         self.system.tracker_miner_fs_wait_for_idle (MINER_FS_IDLE_TIMEOUT)
         self.assertEquals (self.get_urn_count_by_url (dest_fileuri), 0)
@@ -317,7 +318,7 @@ class TrackerCameraVideosApplicationTests (CommonTrackerApplicationTest):
         self.assertEquals (self.get_urn_count_by_url (dest_fileuri), 1)
 
         # Clean the new file so the test directory is as before
-        print "Remove and wait"
+        log ("Remove and wait")
         os.remove (dest_filepath)
         self.system.tracker_miner_fs_wait_for_idle (MINER_FS_IDLE_TIMEOUT)
         self.assertEquals (self.get_urn_count_by_url (dest_fileuri), 0)
